@@ -1,8 +1,6 @@
-#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #' @rdname geom-docs
 #' @export
-#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-geom_bin2d_pattern <- function(mapping = NULL, data = NULL,
+geom_bin_2d_pattern <- function(mapping = NULL, data = NULL,
                        stat = "bin2d", position = "identity",
                        ...,
                        na.rm = FALSE,
@@ -17,24 +15,13 @@ geom_bin2d_pattern <- function(mapping = NULL, data = NULL,
     position = position,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
-    params = list(
+    params = list2(
       na.rm = na.rm,
       ...
     )
   )
 }
 
-
-
-
-if(FALSE) {
-  library(ggplot2)
-
-  ggplot(diamonds, aes(x, y)) + xlim(4, 10) + ylim(4, 10) +
-    geom_bin2d_pattern(aes(pattern_density = ..density..), fill = 'white', bins = 5) +
-    theme_bw() +
-    labs(title = "ggpattern::geom_bin2d()")
-
-}
-
-
+#' @rdname geom-docs
+#' @export
+geom_bin2d_pattern <- geom_bin_2d_pattern
